## Source of Noise Curves

WARNING: Some of these may not (yet) be correct.

If you alter or add any curves to this directory please edit this file appropriately.

### AdLIGO
https://dcc.ligo.org/LIGO-T2000012/public

### AdVirgo
https://dcc.ligo.org/LIGO-P1200087-v42/public

### KAGRA
https://dcc.ligo.org/LIGO-P1200087-v42/public

### Cosmic Explorer
https://dcc.ligo.org/LIGO-P1600143/public

### A+
https://dcc.ligo.org/LIGO-T1500293

### ET
http://www.et-gw.eu/index.php/etsensitivities

### LISA
http://www.srl.caltech.edu/~shane/sensitivity/


### High-frequency detector (NEMO)
Generated by Rob Ward. Consistent with designs for the NEMO detector used in [this paper](https://www.cambridge.org/core/journals/publications-of-the-astronomical-society-of-australia/article/multimessenger-astronomy-with-a-khzband-gravitationalwave-observatory/14FE69AFC2795358FA424623F90DC134). 
